@@ -15,7 +15,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Glib.pm,v 1.62.2.7 2004/06/13 16:23:33 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Glib.pm,v 1.66 2004/06/01 15:40:30 muppetman Exp $
 #
 
 package Glib;
@@ -61,7 +61,7 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = map { @$_ } values %EXPORT_TAGS;
 $EXPORT_TAGS{all} = \@EXPORT_OK;
 
-our $VERSION = '1.043';
+our $VERSION = '1.050';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
@@ -242,14 +242,15 @@ have been registered for you:
 
  G_TYPE_STRING     Glib::String
  G_TYPE_INT        Glib::Int
- G_TYPE_UINT       Glib::Uint
+ G_TYPE_UINT       Glib::UInt
  G_TYPE_DOUBLE     Glib::Double
  G_TYPE_BOOLEAN    Glib::Boolean
 
-The remaining fundamentals (char/uchar, short, float, etc) are left off, since
-perl really only has ints, uints, and doubles anyway.  Oh, and we created a
-GBoxed type for Perl scalars so you can use scalars where any boxed type would
-be allowed (e.g. GtkTreeModel columns):
+The remaining fundamentals (char/uchar, short, float, etc) are also registered
+so that we can properly interact with properties of C objects, but perl really
+only uses ints, uints, and doubles.  Oh, and we created a GBoxed type for Perl
+scalars so you can use scalars where any boxed type would be allowed (e.g.
+GtkTreeModel columns):
 
  Glib::Scalar
 
